@section Targets


Each port of BFD to a different machine requires the creation
of a target back end. All the back end provides to the root
part of BFD is a structure containing pointers to functions
which perform certain low level operations on files. BFD
translates the applications's requests through a pointer into
calls to the back end routines.

When a file is opened with @code{bfd_openr}, its format and
target are unknown. BFD uses various mechanisms to determine
how to interpret the file. The operations performed are:

@itemize @bullet

@item
Create a BFD by calling the internal routine
@code{_bfd_new_bfd}, then call @code{bfd_find_target} with the
target string supplied to @code{bfd_openr} and the new BFD pointer.

@item
If a null target string was provided to @code{bfd_find_target},
look up the environment variable @code{GNUTARGET} and use
that as the target string.

@item
If the target string is still @code{NULL}, or the target string is
@code{default}, then use the first item in the target vector
as the target type, and set @code{target_defaulted} in the BFD to
cause @code{bfd_check_format} to loop through all the targets.
@xref{bfd_target}.  @xref{Formats}.

@item
Otherwise, inspect the elements in the target vector
one by one, until a match on target name is found. When found,
use it.

@item
Otherwise return the error @code{bfd_error_invalid_target} to
@code{bfd_openr}.

@item
@code{bfd_openr} attempts to open the file using
@code{bfd_open_file}, and returns the BFD.
@end itemize
Once the BFD has been opened and the target selected, the file
format may be determined. This is done by calling
@code{bfd_check_format} on the BFD with a suggested format.
If @code{target_defaulted} has been set, each possible target
type is tried to see if it recognizes the specified format.
@code{bfd_check_format} returns @code{TRUE} when the caller guesses right.
@menu
* bfd_target::
@end menu

@node bfd_target,  , Targets, Targets

@subsection bfd_target


This structure contains everything that BFD knows about a
target. It includes things like its byte order, name, and which
routines to call to do various operations.

Every BFD points to a target structure with its @code{xvec}
member.

The macros below are used to dispatch to functions through the
@code{bfd_target} vector. They are used in a number of macros further
down in @file{bfd.h}, and are also used when calling various
routines by hand inside the BFD implementation.  The @var{arglist}
argument must be parenthesized; it contains all the arguments
to the called function.

They make the documentation (more) unpleasant to read, so if
someone wants to fix this and not break the above, please do.
@example
#define BFD_SEND(bfd, message, arglist) \
  ((*((bfd)->xvec->message)) arglist)

#ifdef DEBUG_BFD_SEND
#undef BFD_SEND
#define BFD_SEND(bfd, message, arglist) \
  (((bfd) && (bfd)->xvec && (bfd)->xvec->message) ? \
    ((*((bfd)->xvec->message)) arglist) : \
    (bfd_assert (__FILE__,__LINE__), NULL))
#endif
@end example
For operations which index on the BFD format:
@example
#define BFD_SEND_FMT(bfd, message, arglist) \
  (((bfd)->xvec->message[(int) ((bfd)->format)]) arglist)

#ifdef DEBUG_BFD_SEND
#undef BFD_SEND_FMT
#define BFD_SEND_FMT(bfd, message, arglist) \
  (((bfd) && (bfd)->xvec && (bfd)->xvec->message) ? \
   (((bfd)->xvec->message[(int) ((bfd)->format)]) arglist) : \
   (bfd_assert (__FILE__,__LINE__), NULL))
#endif

/* Defined to TRUE if unused section symbol should be kept.  */
#ifndef TARGET_KEEP_UNUSED_SECTION_SYMBOLS
#define TARGET_KEEP_UNUSED_SECTION_SYMBOLS true
#endif

@end example
This is the structure which defines the type of BFD this is.  The
@code{xvec} member of the struct @code{bfd} itself points here.  Each
module that implements access to a different target under BFD,
defines one of these.

FIXME, these names should be rationalised with the names of
the entry points which call them. Too bad we can't have one
macro to define them both!


@example
typedef struct bfd_target
@{
  /* Identifies the kind of target, e.g., SunOS4, Ultrix, etc.  */
  const char *name;

 /* The "flavour" of a back end is a general indication about
    the contents of a file.  */
  enum bfd_flavour flavour;

  /* The order of bytes within the data area of a file.  */
  enum bfd_endian byteorder;

 /* The order of bytes within the header parts of a file.  */
  enum bfd_endian header_byteorder;

  /* A mask of all the flags which an executable may have set -
     from the set @code{BFD_NO_FLAGS}, @code{HAS_RELOC}, ...@code{D_PAGED}.  */
  flagword object_flags;

 /* A mask of all the flags which a section may have set - from
    the set @code{SEC_NO_FLAGS}, @code{SEC_ALLOC}, ...@code{SET_NEVER_LOAD}.  */
  flagword section_flags;

 /* The character normally found at the front of a symbol.
    (if any), perhaps `_'.  */
  char symbol_leading_char;

 /* The pad character for file names within an archive header.  */
  char ar_pad_char;

  /* The maximum number of characters in an archive header.  */
  unsigned char ar_max_namelen;

  /* How well this target matches, used to select between various
     possible targets when more than one target matches.  */
  unsigned char match_priority;

 /* TRUE if unused section symbols should be kept.  */
  bool keep_unused_section_symbols;

  /* Entries for byte swapping for data. These are different from the
     other entry points, since they don't take a BFD as the first argument.
     Certain other handlers could do the same.  */
  uint64_t       (*bfd_getx64) (const void *);
  int64_t        (*bfd_getx_signed_64) (const void *);
  void           (*bfd_putx64) (uint64_t, void *);
  bfd_vma        (*bfd_getx32) (const void *);
  bfd_signed_vma (*bfd_getx_signed_32) (const void *);
  void           (*bfd_putx32) (bfd_vma, void *);
  bfd_vma        (*bfd_getx16) (const void *);
  bfd_signed_vma (*bfd_getx_signed_16) (const void *);
  void           (*bfd_putx16) (bfd_vma, void *);

  /* Byte swapping for the headers.  */
  uint64_t       (*bfd_h_getx64) (const void *);
  int64_t        (*bfd_h_getx_signed_64) (const void *);
  void           (*bfd_h_putx64) (uint64_t, void *);
  bfd_vma        (*bfd_h_getx32) (const void *);
  bfd_signed_vma (*bfd_h_getx_signed_32) (const void *);
  void           (*bfd_h_putx32) (bfd_vma, void *);
  bfd_vma        (*bfd_h_getx16) (const void *);
  bfd_signed_vma (*bfd_h_getx_signed_16) (const void *);
  void           (*bfd_h_putx16) (bfd_vma, void *);

  /* Format dependent routines: these are vectors of entry points
     within the target vector structure, one for each format to check.  */

  /* Check the format of a file being read.  Return a @code{bfd_cleanup} on
     success or zero on failure.  */
  bfd_cleanup (*_bfd_check_format[bfd_type_end]) (bfd *);

  /* Set the format of a file being written.  */
  bool (*_bfd_set_format[bfd_type_end]) (bfd *);

  /* Write cached information into a file being written, at @code{bfd_close}.  */
  bool (*_bfd_write_contents[bfd_type_end]) (bfd *);

@end example
The general target vector.  These vectors are initialized using the
BFD_JUMP_TABLE macros.
@example
  /* Generic entry points.  */
#define BFD_JUMP_TABLE_GENERIC(NAME) \
  NAME##_close_and_cleanup, \
  NAME##_bfd_free_cached_info, \
  NAME##_new_section_hook, \
  NAME##_get_section_contents, \
  NAME##_get_section_contents_in_window

  /* Called when the BFD is being closed to do any necessary cleanup.  */
  bool (*_close_and_cleanup) (bfd *);
  /* Ask the BFD to free all cached information.  */
  bool (*_bfd_free_cached_info) (bfd *);
  /* Called when a new section is created.  */
  bool (*_new_section_hook) (bfd *, sec_ptr);
  /* Read the contents of a section.  */
  bool (*_bfd_get_section_contents) (bfd *, sec_ptr, void *, file_ptr,
                                     bfd_size_type);
  bool (*_bfd_get_section_contents_in_window) (bfd *, sec_ptr, bfd_window *,
                                               file_ptr, bfd_size_type);

  /* Entry points to copy private data.  */
#define BFD_JUMP_TABLE_COPY(NAME) \
  NAME##_bfd_copy_private_bfd_data, \
  NAME##_bfd_merge_private_bfd_data, \
  _bfd_generic_init_private_section_data, \
  NAME##_bfd_copy_private_section_data, \
  NAME##_bfd_copy_private_symbol_data, \
  NAME##_bfd_copy_private_header_data, \
  NAME##_bfd_set_private_flags, \
  NAME##_bfd_print_private_bfd_data

  /* Called to copy BFD general private data from one object file
     to another.  */
  bool (*_bfd_copy_private_bfd_data) (bfd *, bfd *);
  /* Called to merge BFD general private data from one object file
     to a common output file when linking.  */
  bool (*_bfd_merge_private_bfd_data) (bfd *, struct bfd_link_info *);
  /* Called to initialize BFD private section data from one object file
     to another.  */
#define bfd_init_private_section_data(ibfd, isec, obfd, osec, link_info) \
       BFD_SEND (obfd, _bfd_init_private_section_data, \
                 (ibfd, isec, obfd, osec, link_info))
  bool (*_bfd_init_private_section_data) (bfd *, sec_ptr, bfd *, sec_ptr,
                                          struct bfd_link_info *);
  /* Called to copy BFD private section data from one object file
     to another.  */
  bool (*_bfd_copy_private_section_data) (bfd *, sec_ptr, bfd *, sec_ptr);
  /* Called to copy BFD private symbol data from one symbol
     to another.  */
  bool (*_bfd_copy_private_symbol_data) (bfd *, asymbol *,
                                         bfd *, asymbol *);
  /* Called to copy BFD private header data from one object file
     to another.  */
  bool (*_bfd_copy_private_header_data) (bfd *, bfd *);
  /* Called to set private backend flags.  */
  bool (*_bfd_set_private_flags) (bfd *, flagword);

  /* Called to print private BFD data.  */
  bool (*_bfd_print_private_bfd_data) (bfd *, void *);

  /* Core file entry points.  */
#define BFD_JUMP_TABLE_CORE(NAME) \
  NAME##_core_file_failing_command, \
  NAME##_core_file_failing_signal, \
  NAME##_core_file_matches_executable_p, \
  NAME##_core_file_pid

  char *(*_core_file_failing_command) (bfd *);
  int   (*_core_file_failing_signal) (bfd *);
  bool  (*_core_file_matches_executable_p) (bfd *, bfd *);
  int   (*_core_file_pid) (bfd *);

  /* Archive entry points.  */
#define BFD_JUMP_TABLE_ARCHIVE(NAME) \
  NAME##_slurp_armap, \
  NAME##_slurp_extended_name_table, \
  NAME##_construct_extended_name_table, \
  NAME##_truncate_arname, \
  NAME##_write_armap, \
  NAME##_read_ar_hdr, \
  NAME##_write_ar_hdr, \
  NAME##_openr_next_archived_file, \
  NAME##_get_elt_at_index, \
  NAME##_generic_stat_arch_elt, \
  NAME##_update_armap_timestamp

  bool (*_bfd_slurp_armap) (bfd *);
  bool (*_bfd_slurp_extended_name_table) (bfd *);
  bool (*_bfd_construct_extended_name_table) (bfd *, char **,
                                              bfd_size_type *,
                                              const char **);
  void (*_bfd_truncate_arname) (bfd *, const char *, char *);
  bool (*write_armap) (bfd *, unsigned, struct orl *, unsigned, int);
  void *(*_bfd_read_ar_hdr_fn) (bfd *);
  bool (*_bfd_write_ar_hdr_fn) (bfd *, bfd *);
  bfd *(*openr_next_archived_file) (bfd *, bfd *);
#define bfd_get_elt_at_index(b,i) \
       BFD_SEND (b, _bfd_get_elt_at_index, (b,i))
  bfd *(*_bfd_get_elt_at_index) (bfd *, symindex);
  int  (*_bfd_stat_arch_elt) (bfd *, struct stat *);
  bool (*_bfd_update_armap_timestamp) (bfd *);

  /* Entry points used for symbols.  */
#define BFD_JUMP_TABLE_SYMBOLS(NAME) \
  NAME##_get_symtab_upper_bound, \
  NAME##_canonicalize_symtab, \
  NAME##_make_empty_symbol, \
  NAME##_print_symbol, \
  NAME##_get_symbol_info, \
  NAME##_get_symbol_version_string, \
  NAME##_bfd_is_local_label_name, \
  NAME##_bfd_is_target_special_symbol, \
  NAME##_get_lineno, \
  NAME##_find_nearest_line, \
  NAME##_find_nearest_line_with_alt, \
  NAME##_find_line, \
  NAME##_find_inliner_info, \
  NAME##_bfd_make_debug_symbol, \
  NAME##_read_minisymbols, \
  NAME##_minisymbol_to_symbol

  long (*_bfd_get_symtab_upper_bound) (bfd *);
  long (*_bfd_canonicalize_symtab) (bfd *, struct bfd_symbol **);
  struct bfd_symbol *
       (*_bfd_make_empty_symbol) (bfd *);
  void (*_bfd_print_symbol) (bfd *, void *, struct bfd_symbol *,
                             bfd_print_symbol_type);
#define bfd_print_symbol(b,p,s,e) \
       BFD_SEND (b, _bfd_print_symbol, (b,p,s,e))
  void  (*_bfd_get_symbol_info) (bfd *, struct bfd_symbol *, symbol_info *);
#define bfd_get_symbol_info(b,p,e) \
       BFD_SEND (b, _bfd_get_symbol_info, (b,p,e))
  const char *
       (*_bfd_get_symbol_version_string) (bfd *, struct bfd_symbol *,
                                          bool, bool *);
#define bfd_get_symbol_version_string(b,s,p,h) \
       BFD_SEND (b, _bfd_get_symbol_version_string, (b,s,p,h))
  bool (*_bfd_is_local_label_name) (bfd *, const char *);
  bool (*_bfd_is_target_special_symbol) (bfd *, asymbol *);
  alent *
       (*_get_lineno) (bfd *, struct bfd_symbol *);
  bool (*_bfd_find_nearest_line) (bfd *, struct bfd_symbol **,
                                  struct bfd_section *, bfd_vma,
                                  const char **, const char **,
                                  unsigned int *, unsigned int *);
  bool (*_bfd_find_nearest_line_with_alt) (bfd *, const char *,
                                           struct bfd_symbol **,
                                           struct bfd_section *, bfd_vma,
                                           const char **, const char **,
                                           unsigned int *, unsigned int *);
  bool (*_bfd_find_line) (bfd *, struct bfd_symbol **,
                          struct bfd_symbol *, const char **,
                          unsigned int *);
  bool (*_bfd_find_inliner_info)
    (bfd *, const char **, const char **, unsigned int *);
 /* Back-door to allow format-aware applications to create debug symbols
    while using BFD for everything else.  Currently used by the assembler
    when creating COFF files.  */
  asymbol *
       (*_bfd_make_debug_symbol) (bfd *);
#define bfd_read_minisymbols(b, d, m, s) \
       BFD_SEND (b, _read_minisymbols, (b, d, m, s))
  long (*_read_minisymbols) (bfd *, bool, void **, unsigned int *);
#define bfd_minisymbol_to_symbol(b, d, m, f) \
       BFD_SEND (b, _minisymbol_to_symbol, (b, d, m, f))
  asymbol *
       (*_minisymbol_to_symbol) (bfd *, bool, const void *, asymbol *);

  /* Routines for relocs.  */
#define BFD_JUMP_TABLE_RELOCS(NAME) \
  NAME##_get_reloc_upper_bound, \
  NAME##_canonicalize_reloc, \
  NAME##_set_reloc, \
  NAME##_bfd_reloc_type_lookup, \
  NAME##_bfd_reloc_name_lookup

  long (*_get_reloc_upper_bound) (bfd *, sec_ptr);
  long (*_bfd_canonicalize_reloc) (bfd *, sec_ptr, arelent **,
                                   struct bfd_symbol **);
  void (*_bfd_set_reloc) (bfd *, sec_ptr, arelent **, unsigned int);
  /* See documentation on reloc types.  */
  reloc_howto_type *
       (*reloc_type_lookup) (bfd *, bfd_reloc_code_real_type);
  reloc_howto_type *
       (*reloc_name_lookup) (bfd *, const char *);

  /* Routines used when writing an object file.  */
#define BFD_JUMP_TABLE_WRITE(NAME) \
  NAME##_set_arch_mach, \
  NAME##_set_section_contents

  bool (*_bfd_set_arch_mach) (bfd *, enum bfd_architecture,
                                     unsigned long);
  bool (*_bfd_set_section_contents) (bfd *, sec_ptr, const void *,
                                     file_ptr, bfd_size_type);

  /* Routines used by the linker.  */
#define BFD_JUMP_TABLE_LINK(NAME) \
  NAME##_sizeof_headers, \
  NAME##_bfd_get_relocated_section_contents, \
  NAME##_bfd_relax_section, \
  NAME##_bfd_link_hash_table_create, \
  NAME##_bfd_link_add_symbols, \
  NAME##_bfd_link_just_syms, \
  NAME##_bfd_copy_link_hash_symbol_type, \
  NAME##_bfd_final_link, \
  NAME##_bfd_link_split_section, \
  NAME##_bfd_link_check_relocs, \
  NAME##_bfd_gc_sections, \
  NAME##_bfd_lookup_section_flags, \
  NAME##_bfd_merge_sections, \
  NAME##_bfd_is_group_section, \
  NAME##_bfd_group_name, \
  NAME##_bfd_discard_group, \
  NAME##_section_already_linked, \
  NAME##_bfd_define_common_symbol, \
  NAME##_bfd_link_hide_symbol, \
  NAME##_bfd_define_start_stop

  int  (*_bfd_sizeof_headers) (bfd *, struct bfd_link_info *);
  bfd_byte *
       (*_bfd_get_relocated_section_contents) (bfd *,
                                               struct bfd_link_info *,
                                               struct bfd_link_order *,
                                               bfd_byte *, bool,
                                               struct bfd_symbol **);

  bool (*_bfd_relax_section) (bfd *, struct bfd_section *,
                              struct bfd_link_info *, bool *);

  /* Create a hash table for the linker.  Different backends store
     different information in this table.  */
  struct bfd_link_hash_table *
       (*_bfd_link_hash_table_create) (bfd *);

  /* Add symbols from this object file into the hash table.  */
  bool (*_bfd_link_add_symbols) (bfd *, struct bfd_link_info *);

  /* Indicate that we are only retrieving symbol values from this section.  */
  void (*_bfd_link_just_syms) (asection *, struct bfd_link_info *);

  /* Copy the symbol type and other attributes for a linker script
     assignment of one symbol to another.  */
#define bfd_copy_link_hash_symbol_type(b, t, f) \
       BFD_SEND (b, _bfd_copy_link_hash_symbol_type, (b, t, f))
  void (*_bfd_copy_link_hash_symbol_type) (bfd *,
                                           struct bfd_link_hash_entry *,
                                           struct bfd_link_hash_entry *);

  /* Do a link based on the link_order structures attached to each
     section of the BFD.  */
  bool (*_bfd_final_link) (bfd *, struct bfd_link_info *);

  /* Should this section be split up into smaller pieces during linking.  */
  bool (*_bfd_link_split_section) (bfd *, struct bfd_section *);

  /* Check the relocations in the bfd for validity.  */
  bool (* _bfd_link_check_relocs)(bfd *, struct bfd_link_info *);

  /* Remove sections that are not referenced from the output.  */
  bool (*_bfd_gc_sections) (bfd *, struct bfd_link_info *);

  /* Sets the bitmask of allowed and disallowed section flags.  */
  bool (*_bfd_lookup_section_flags) (struct bfd_link_info *,
                                     struct flag_info *, asection *);

  /* Attempt to merge SEC_MERGE sections.  */
  bool (*_bfd_merge_sections) (bfd *, struct bfd_link_info *);

  /* Is this section a member of a group?  */
  bool (*_bfd_is_group_section) (bfd *, const struct bfd_section *);

  /* The group name, if section is a member of a group.  */
  const char *(*_bfd_group_name) (bfd *, const struct bfd_section *);

  /* Discard members of a group.  */
  bool (*_bfd_discard_group) (bfd *, struct bfd_section *);

  /* Check if SEC has been already linked during a reloceatable or
     final link.  */
  bool (*_section_already_linked) (bfd *, asection *,
                                   struct bfd_link_info *);

  /* Define a common symbol.  */
  bool (*_bfd_define_common_symbol) (bfd *, struct bfd_link_info *,
                                     struct bfd_link_hash_entry *);

  /* Hide a symbol.  */
  void (*_bfd_link_hide_symbol) (bfd *, struct bfd_link_info *,
                                 struct bfd_link_hash_entry *);

  /* Define a __start, __stop, .startof. or .sizeof. symbol.  */
  struct bfd_link_hash_entry *
       (*_bfd_define_start_stop) (struct bfd_link_info *, const char *,
                                  asection *);

  /* Routines to handle dynamic symbols and relocs.  */
#define BFD_JUMP_TABLE_DYNAMIC(NAME) \
  NAME##_get_dynamic_symtab_upper_bound, \
  NAME##_canonicalize_dynamic_symtab, \
  NAME##_get_synthetic_symtab, \
  NAME##_get_dynamic_reloc_upper_bound, \
  NAME##_canonicalize_dynamic_reloc

  /* Get the amount of memory required to hold the dynamic symbols.  */
  long (*_bfd_get_dynamic_symtab_upper_bound) (bfd *);
  /* Read in the dynamic symbols.  */
  long (*_bfd_canonicalize_dynamic_symtab) (bfd *, struct bfd_symbol **);
  /* Create synthetized symbols.  */
  long (*_bfd_get_synthetic_symtab) (bfd *, long, struct bfd_symbol **,
                                     long, struct bfd_symbol **,
                                     struct bfd_symbol **);
  /* Get the amount of memory required to hold the dynamic relocs.  */
  long (*_bfd_get_dynamic_reloc_upper_bound) (bfd *);
  /* Read in the dynamic relocs.  */
  long (*_bfd_canonicalize_dynamic_reloc) (bfd *, arelent **,
                                           struct bfd_symbol **);

@end example
A pointer to an alternative bfd_target in case the current one is not
satisfactory.  This can happen when the target cpu supports both big
and little endian code, and target chosen by the linker has the wrong
endianness.  The function open_output() in ld/ldlang.c uses this field
to find an alternative output format that is suitable.
@example
  /* Opposite endian version of this target.  */
  const struct bfd_target *alternative_target;

  /* Data for use by back-end routines, which isn't
     generic enough to belong in this structure.  */
  const void *backend_data;

@} bfd_target;

static inline const char *
bfd_get_target (const bfd *abfd)
@{
  return abfd->xvec->name;
@}

static inline enum bfd_flavour
bfd_get_flavour (const bfd *abfd)
@{
  return abfd->xvec->flavour;
@}

static inline flagword
bfd_applicable_file_flags (const bfd *abfd)
@{
  return abfd->xvec->object_flags;
@}

static inline bool
bfd_family_coff (const bfd *abfd)
@{
  return (bfd_get_flavour (abfd) == bfd_target_coff_flavour
          || bfd_get_flavour (abfd) == bfd_target_xcoff_flavour);
@}

static inline bool
bfd_big_endian (const bfd *abfd)
@{
  return abfd->xvec->byteorder == BFD_ENDIAN_BIG;
@}
static inline bool
bfd_little_endian (const bfd *abfd)
@{
  return abfd->xvec->byteorder == BFD_ENDIAN_LITTLE;
@}

static inline bool
bfd_header_big_endian (const bfd *abfd)
@{
  return abfd->xvec->header_byteorder == BFD_ENDIAN_BIG;
@}

static inline bool
bfd_header_little_endian (const bfd *abfd)
@{
  return abfd->xvec->header_byteorder == BFD_ENDIAN_LITTLE;
@}

static inline flagword
bfd_applicable_section_flags (const bfd *abfd)
@{
  return abfd->xvec->section_flags;
@}

static inline char
bfd_get_symbol_leading_char (const bfd *abfd)
@{
  return abfd->xvec->symbol_leading_char;
@}

static inline enum bfd_flavour
bfd_asymbol_flavour (const asymbol *sy)
@{
  if ((sy->flags & BSF_SYNTHETIC) != 0)
    return bfd_target_unknown_flavour;
  return sy->the_bfd->xvec->flavour;
@}

static inline bool
bfd_keep_unused_section_symbols (const bfd *abfd)
@{
  return abfd->xvec->keep_unused_section_symbols;
@}

@end example
@findex _bfd_per_xvec_warn
@subsubsection @code{_bfd_per_xvec_warn}
@deftypefn {Function} struct per_xvec_message **_bfd_per_xvec_warn (const bfd_target *, size_t); 
Return a location for the given target xvec to use for
warnings specific to that target.  If TARG is NULL, returns
the array of per_xvec_message pointers, otherwise if ALLOC is
zero, returns a pointer to a pointer to the list of messages
for TARG, otherwise (both TARG and ALLOC non-zero), allocates
a new   per_xvec_message with space for a string of ALLOC
bytes and returns a pointer to a pointer to it.  May return a
pointer to a NULL pointer on allocation failure.

@end deftypefn
@findex bfd_set_default_target
@subsubsection @code{bfd_set_default_target}
@deftypefn {Function} bool bfd_set_default_target (const char *name); 
Set the default target vector to use when recognizing a BFD.
This takes the name of the target, which may be a BFD target
name or a configuration triplet.

@end deftypefn
@findex bfd_find_target
@subsubsection @code{bfd_find_target}
@deftypefn {Function} const bfd_target *bfd_find_target (const char *target_name, bfd *abfd); 
Return a pointer to the transfer vector for the object target
named @var{target_name}.  If @var{target_name} is @code{NULL},
choose the one in the environment variable @code{GNUTARGET}; if
that is null or not defined, then choose the first entry in the
target list.  Passing in the string "default" or setting the
environment variable to "default" will cause the first entry in
the target list to be returned, and "target_defaulted" will be
set in the BFD if @var{abfd} isn't @code{NULL}.  This causes
@code{bfd_check_format} to loop over all the targets to find the
one that matches the file being read.

@end deftypefn
@findex bfd_get_target_info
@subsubsection @code{bfd_get_target_info}
@deftypefn {Function} const bfd_target *bfd_get_target_info (const char *target_name, bfd *abfd, bool *is_bigendian, int *underscoring, const char **def_target_arch); 
Return a pointer to the transfer vector for the object target
named @var{target_name}.  If @var{target_name} is @code{NULL},
choose the one in the environment variable @code{GNUTARGET}; if
that is null or not defined, then choose the first entry in the
target list.  Passing in the string "default" or setting the
environment variable to "default" will cause the first entry in
the target list to be returned, and "target_defaulted" will be
set in the BFD if @var{abfd} isn't @code{NULL}.  This causes
@code{bfd_check_format} to loop over all the targets to find the
one that matches the file being read.
If @var{is_bigendian} is not @code{NULL}, then set this value to target's
endian mode. True for big-endian, FALSE for little-endian or for
invalid target.
If @var{underscoring} is not @code{NULL}, then set this value to target's
underscoring mode. Zero for none-underscoring, -1 for invalid target,
else the value of target vector's symbol underscoring.
If @var{def_target_arch} is not @code{NULL}, then set it to the architecture
string specified by the target_name.

@end deftypefn
@findex bfd_target_list
@subsubsection @code{bfd_target_list}
@deftypefn {Function} const char ** bfd_target_list (void); 
Return a freshly malloced NULL-terminated
vector of the names of all the valid BFD targets. Do not
modify the names.

@end deftypefn
@findex bfd_iterate_over_targets
@subsubsection @code{bfd_iterate_over_targets}
@deftypefn {Function} const bfd_target *bfd_iterate_over_targets (int (*func) (const bfd_target *, void *), void *data); 
Call @var{func} for each target in the list of BFD target
vectors, passing @var{data} to @var{func}.  Stop iterating if
@var{func} returns a non-zero result, and return that target
vector.  Return NULL if @var{func} always returns zero.

@end deftypefn
@findex bfd_flavour_name
@subsubsection @code{bfd_flavour_name}
@deftypefn {Function} const char *bfd_flavour_name (enum bfd_flavour flavour); 
Return the string form of @var{flavour}.

@end deftypefn
